@@ -141,6 +141,13 @@ class GraphBase:
             plt.rcParams['ytick.direction'] = direction
         return self
 
+    def grid(self, *args, **kwargs):
+        if self.ax is not None:
+            self.ax.grid(*args, **kwargs)
+        else:
+            plt.grid(*args, **kwargs)
+        return self
+
     def xlim(self, *args, **kwargs):
         if self.ax is not None:
             self.ax.set_xlim(*args, **kwargs)
